commit
stringlengths
40
40
subject
stringlengths
4
1.73k
repos
stringlengths
5
127k
old_file
stringlengths
2
751
new_file
stringlengths
2
751
new_contents
stringlengths
1
8.98k
old_contents
stringlengths
0
6.59k
license
stringclasses
13 values
lang
stringclasses
23 values
7cad8dec41815f703a283610a2d27c3e5b6a4b32
add transform_output_iterator testing
sdalton1/thrust,egaburov/thrust,sdalton1/thrust,egaburov/thrust,sdalton1/thrust,egaburov/thrust
testing/transform_output_iterator.cu
testing/transform_output_iterator.cu
#include <unittest/unittest.h> #include <thrust/iterator/transform_output_iterator.h> #include <thrust/copy.h> #include <thrust/reduce.h> #include <thrust/functional.h> #include <thrust/sequence.h> #include <thrust/iterator/counting_iterator.h> template <class Vector> void TestTransformOutputIterator(void) { type...
apache-2.0
Cuda
d3c516423130a1b946ec88d5daf614f4ada686a0
Create xor-popcnt-accum.cu
gpu0/cuda-code,gpu0/cuda-code
xor/xor-popcnt-accum.cu
xor/xor-popcnt-accum.cu
#include<iostream> #include <stdio.h> #define ITER 1024*1024*16 #define SSZ 512 #define BSZ 7*4 #include <time.h> #include <sys/time.h> #define USECPSEC 1000000ULL unsigned long long dtime_usec(unsigned long long start){ timeval tv; gettimeofday(&tv, 0); return ((tv.tv_sec*USECPSEC)+tv.tv_usec)-start; } __g...
bsd-3-clause
Cuda
009c4bb3434d9cba0bee4281ec413253f750d412
Add Nathan's weld_vertices example
google-code-export/thrust,julianromera/thrust,UIKit0/thrust,julianromera/thrust,rdmenezes/thrust,bfurtaw/thrust,lishi0927/thrust,bfurtaw/thrust,julianromera/thrust,lishi0927/thrust,levendlee/thrust,h1arshad/thrust,hemmingway/thrust,lishi0927/thrust,allendaicool/thrust,malenie/thrust,levendlee/thrust,malenie/thrust,hemm...
examples/weld_vertices.cu
examples/weld_vertices.cu
#include <thrust/device_vector.h> #include <thrust/remove.h> #include <thrust/unique.h> #include <thrust/binary_search.h> #include <thrust/sort.h> #include <iostream> // This example "welds" triangle vertices together by taking as // input "triangle soup" and eliminating redundant vertex positions // and shared ed...
apache-2.0
Cuda
4d523055a6cae6670879929964fb290b48c72eb0
add Texture Object basic frame
stormHan/Cuda,stormHan/Cuda
Demo/textureObj.cu
Demo/textureObj.cu
/* Practise the Texture memory to help me understand the cuda DateTime 2016.05.10 */ #include "cuda_runtime.h" #include "device_launch_parameters.h" #include <stdio.h> #include <malloc.h> #include <Windows.h> //Texture Object //struct cudaTextureDesc //{ // enum cudaTextureAddressMode addressMode[3]; // enum cuda...
mit
Cuda
1f507fc009b74a116ab630f2b5b0d98700eaf864
Create transpose.cu
alchemz/CUDA_Concurrent_Programming_Research,alchemz/CUDA_Concurrent_Programming_Research
transpose-matrix/transpose.cu
transpose-matrix/transpose.cu
#include <stdio.h> #include "gputimer.h" const int N = 1024; void transpose_CPU(float in[], float out[]){ for(int j=0; j<N; j++){ for(int i=0; i<N; i++){ out[j + i*N] = in[i + j*N]; //out(j, i)=in(i, j) } } } int main(int argc, char** argv){ int numbytes = N*N*sizeof(float); float *...
mit
Cuda
32555ba481815f25b4231060c9937e2b443a8342
Test set_difference with thrust::seq in __device__ code.
sdalton1/thrust,xiongzhanblake/thrust,arnabgho/thrust,raygit/thrust,dachziegel/thrust,jaredhoberock/thrust,GrimDerp/thrust,xiongzhanblake/thrust_src,zhenglaizhang/thrust,jaredhoberock/thrust,jaredhoberock/thrust,thrust/thrust,sdalton1/thrust,zeryx/thrust,xiongzhanblake/thrust_src,andrewcorrigan/thrust-multi-permutation...
testing/backend/cuda/set_difference.cu
testing/backend/cuda/set_difference.cu
#include <unittest/unittest.h> #include <thrust/set_operations.h> #include <thrust/execution_policy.h> template<typename Iterator1, typename Iterator2, typename Iterator3, typename Iterator4> __global__ void set_difference_kernel(Iterator1 first1, Iterator1 last1, Iterator2 first2, Iterator2 last2, Iterator3 result1,...
apache-2.0
Cuda
b26325dbf7f57310a2d661bb9e3eb8de0ed95c24
Add testing/cudart.cu Add TestCudaMemcpyD2DNullPointerError Add TestCudaMallocResultAligned
mohamed-ali/thrust,xiongzhanblake/thrust,raygit/thrust,GrimDerp/thrust,jaredhoberock/thrust,marksantos/thrust,arnabgho/thrust,dachziegel/thrust,thrust/thrust,arnabgho/thrust,zhenglaizhang/thrust,egaburov/thrust,sarvex/thrust,Ricardo666666/thrust,mohamed-ali/thrust,arnabgho/thrust,egaburov/thrust,Ricardo666666/thrust,th...
testing/cudart.cu
testing/cudart.cu
#include <unittest/unittest.h> #include <cuda_runtime_api.h> #include <thrust/detail/util/align.h> void TestCudaMemcpyD2DNullPointerError(void) { cudaError_t result1 = cudaMemcpy((void*)0, (void*)0, 1, cudaMemcpyDeviceToDevice); cudaError_t result2 = cudaGetLastError(); ASSERT_EQUAL(cudaErrorInvalidValue, resul...
apache-2.0
Cuda
6d85d360939e6853a2332c0152c667300472807b
Test equal with thrust::seq in __device__ code.
zeryx/thrust,egaburov/thrust,marksantos/thrust,arnabgho/thrust,sdalton1/thrust,jaredhoberock/thrust,xiongzhanblake/thrust_src,sarvex/thrust,dachziegel/thrust,zhenglaizhang/thrust,thvasilo/thrust,marksantos/thrust,raygit/thrust,dachziegel/thrust,andrewcorrigan/thrust-multi-permutation-iterator,Ricardo666666/thrust,sarve...
testing/backend/cuda/equal.cu
testing/backend/cuda/equal.cu
#include <unittest/unittest.h> #include <thrust/equal.h> #include <thrust/functional.h> #include <thrust/execution_policy.h> template<typename Iterator1, typename Iterator2, typename Iterator3> __global__ void equal_kernel(Iterator1 first1, Iterator1 last1, Iterator2 first2, Iterator3 result) { *result = thrust::eq...
apache-2.0
Cuda
439511ae243aa6eb8ecf4a74dd5ffc33ea38fd80
Test generate & generate_n with thrust::seq in __device__ code.
Ricardo666666/thrust,mohamed-ali/thrust,GrimDerp/thrust,thrust/thrust,zeryx/thrust,sarvex/thrust,jaredhoberock/thrust,arnabgho/thrust,jaredhoberock/thrust,egaburov/thrust,thvasilo/thrust,sarvex/thrust,arnabgho/thrust,andrewcorrigan/thrust-multi-permutation-iterator,thrust/thrust,Ricardo666666/thrust,sdalton1/thrust,Ric...
testing/backend/cuda/generate.cu
testing/backend/cuda/generate.cu
#include <unittest/unittest.h> #include <thrust/generate.h> #include <thrust/execution_policy.h> template<typename Iterator, typename Function> __global__ void generate_kernel(Iterator first, Iterator last, Function f) { thrust::generate(thrust::seq, first, last, f); } template<typename T> struct return_value { ...
apache-2.0
Cuda
955fe7dfaa9ffb3a7040ff562d8b276eba86bcd3
Add initial matrix tranpose example program
egaburov/agency,egaburov/agency
examples/transpose.cu
examples/transpose.cu
#include <cstdio> #include <cassert> #include <algorithm> #include <numeric> #include <thrust/device_vector.h> #include <thrust/host_vector.h> #include <agency/cuda/execution_policy.hpp> #include <chrono> // XXX need to figure out how to make this par(con) select grid_executor_2d automatically auto grid(agency::size2 ...
bsd-3-clause
Cuda
aad2deb079aeb00a65d56f8f31971f43e4d6d752
Test swap_ranges with thrust:seq in __device__ code.
andrewcorrigan/thrust-multi-permutation-iterator,Ricardo666666/thrust,xiongzhanblake/thrust_src,marksantos/thrust,arnabgho/thrust,zhenglaizhang/thrust,jaredhoberock/thrust,thrust/thrust,sdalton1/thrust,raygit/thrust,zeryx/thrust,zhenglaizhang/thrust,egaburov/thrust,marksantos/thrust,xiongzhanblake/thrust,jaredhoberock/...
testing/backend/cuda/swap_ranges.cu
testing/backend/cuda/swap_ranges.cu
#include <unittest/unittest.h> #include <thrust/swap.h> #include <thrust/execution_policy.h> template<typename Iterator1, typename Iterator2> __global__ void swap_ranges_kernel(Iterator1 first1, Iterator1 last1, Iterator2 first2) { thrust::swap_ranges(thrust::seq, first1, last1, first2); } void TestSwapRangesDevi...
apache-2.0
Cuda
55fc224714096d5fa3b726424eab202d013590ea
Add cuda_grid.cu example
egaburov/agency,egaburov/agency
cuda_grid.cu
cuda_grid.cu
#include <agency/cuda/execution_policy.hpp> #include <agency/execution_policy.hpp> #include <iostream> #include <typeinfo> struct kernel { __device__ void operator()(agency::parallel_group<agency::cuda::concurrent_agent>& self) { printf("hello from {%d, %d}\n", (int)self.outer().index(), (int)self.inner().in...
bsd-3-clause
Cuda
162f75a4686bd32c053d7b5dc5100001fdae4567
Add CUDA test for shared variables
egaburov/agency,egaburov/agency
test_shared.cu
test_shared.cu
#include <agency/cuda/execution_policy.hpp> #include <agency/cuda/grid_executor.hpp> #include <thrust/device_vector.h> #include <cstdio> #include <cassert> template<class T> __device__ T fetch_and_add(T* ptr, T value) { #ifdef __NVCC__ return atomicAdd(ptr, value); #else return __sync_fetch_and_add(ptr, value); #...
bsd-3-clause
Cuda
f771d047d05e71e14fccf10a6381a3e61afb1524
add the texture memory method about mat mul
stormHan/Cuda,stormHan/Cuda
Demo/texMem.cu
Demo/texMem.cu
/* Use the texture memory to optimize the Matrix Multiplication 2016.05.14 */ #include <cuda_runtime.h> #include <device_launch_parameters.h> #include <stdio.h> #include <Windows.h> #include <time.h> texture<float, 2, cudaReadModeElementType> texA; texture<float, 2, cudaReadModeElementType> texB; __global__ vo...
mit
Cuda
4d625aae0baac510c21ebd60f47c94dab914bad8
Add example_headers/constant_header.cuh for testing constant array lookup from header
NVIDIA/jitify,NVIDIA/jitify
example_headers/constant_header.cuh
example_headers/constant_header.cuh
/* * Copyright (c) 2017, NVIDIA CORPORATION. All rights reserved. * * Redistribution and use in source and binary forms, with or without * modification, are permitted provided that the following conditions * are met: * * Redistributions of source code must retain the above copyright * notice, this list of cond...
bsd-3-clause
Cuda
c3263683a2a56b8fc47be1e0dc64f7f3d2ad9ec3
Test scan algorithms with thrust::seq in __device__ code.
zeryx/thrust,thrust/thrust,thvasilo/thrust,marksantos/thrust,raygit/thrust,jaredhoberock/thrust,thrust/thrust,Ricardo666666/thrust,thvasilo/thrust,zhenglaizhang/thrust,xiongzhanblake/thrust_src,mohamed-ali/thrust,xiongzhanblake/thrust_src,xiongzhanblake/thrust,sarvex/thrust,raygit/thrust,xiongzhanblake/thrust,mohamed-a...
testing/backend/cuda/scan.cu
testing/backend/cuda/scan.cu
#include <cstdio> #include <unittest/unittest.h> #include <thrust/scan.h> #include <thrust/functional.h> template<typename Iterator1, typename Iterator2> __global__ void inclusive_scan_kernel(Iterator1 first, Iterator1 last, Iterator2 result) { thrust::inclusive_scan(thrust::seq, first, last, result); } template<...
apache-2.0
Cuda
2f3bb733d95ed9dd1afb581d8559e53735768a59
Test thrust::seq + adjacent_difference in __device__ code.
sarvex/thrust,jaredhoberock/thrust,andrewcorrigan/thrust-multi-permutation-iterator,xiongzhanblake/thrust,marksantos/thrust,thrust/thrust,GrimDerp/thrust,xiongzhanblake/thrust,xiongzhanblake/thrust_src,thrust/thrust,thrust/thrust,thvasilo/thrust,mohamed-ali/thrust,zeryx/thrust,zhenglaizhang/thrust,sdalton1/thrust,andre...
testing/backend/cuda/adjacent_difference.cu
testing/backend/cuda/adjacent_difference.cu
#include <unittest/unittest.h> #include <thrust/adjacent_difference.h> #include <thrust/execution_policy.h> template<typename Iterator1, typename Iterator2> __global__ void adjacent_difference_kernel(Iterator1 first, Iterator1 last, Iterator2 result) { thrust::adjacent_difference(thrust::seq, first, last, result); ...
apache-2.0
Cuda
8faaa9179cb55d45f132bdbc6ccd03fc6c0f2113
Test reduce with thrust::seq in __device__ code.
sdalton1/thrust,xiongzhanblake/thrust_src,Ricardo666666/thrust,jaredhoberock/thrust,sdalton1/thrust,marksantos/thrust,zhenglaizhang/thrust,mohamed-ali/thrust,thrust/thrust,marksantos/thrust,raygit/thrust,andrewcorrigan/thrust-multi-permutation-iterator,thrust/thrust,thrust/thrust,arnabgho/thrust,xiongzhanblake/thrust,z...
testing/backend/cuda/reduce.cu
testing/backend/cuda/reduce.cu
#include <unittest/unittest.h> #include <thrust/reduce.h> #include <thrust/execution_policy.h> template<typename Iterator, typename T, typename Iterator2> __global__ void reduce_kernel(Iterator first, Iterator last, T init, Iterator2 result) { *result = thrust::reduce(thrust::seq, first, last, init); } template<t...
apache-2.0
Cuda
c1634ec9802a2ff401d061e23163e32514134314
Add cuda_device_info utility program
myrtleTree33/Halide,ayanazmat/Halide,gchauras/Halide,aam/Halide,mcanthony/Halide,fengzhyuan/Halide,ayanazmat/Halide,dan-tull/Halide,aam/Halide,kgnk/Halide,psuriana/Halide,lglucin/Halide,aam/Halide,mikeseven/Halide,ronen/Halide,tdenniston/Halide,kenkuang1213/Halide,jiawen/Halide,adasworks/Halide,lglucin/Halide,dougkwan/...
experiments/cuda_device_info.cu
experiments/cuda_device_info.cu
#include <stdio.h> // Print device properties void printDevProp(cudaDeviceProp devProp) { printf("Major revision number: %d\n", devProp.major); printf("Minor revision number: %d\n", devProp.minor); printf("Name: %s\n", devProp.name); printf("Total global memo...
mit
Cuda
8926f50f8a2f9aa978623ed754cd714325fb5542
Add AssertCuda checks
naliboff/dealii,sairajat/dealii,sairajat/dealii,sairajat/dealii,sairajat/dealii,naliboff/dealii,naliboff/dealii,naliboff/dealii,sairajat/dealii,sairajat/dealii,naliboff/dealii,sairajat/dealii,naliboff/dealii,naliboff/dealii
tests/quick_tests/cuda.cu
tests/quick_tests/cuda.cu
// --------------------------------------------------------------------- // // Copyright (C) 2017 by the deal.II authors // // This file is part of the deal.II library. // // The deal.II library is free software; you can use it, redistribute // it, and/or modify it under the terms of the GNU Lesser General // Public Li...
// --------------------------------------------------------------------- // // Copyright (C) 2017 by the deal.II authors // // This file is part of the deal.II library. // // The deal.II library is free software; you can use it, redistribute // it, and/or modify it under the terms of the GNU Lesser General // Public Li...
lgpl-2.1
Cuda
bcfb8778a23a49133b90624fcd20546a141791e1
Test find, find_if, and find_if_not with thrust::seq in __device__ code.
raygit/thrust,zeryx/thrust,egaburov/thrust,mohamed-ali/thrust,mohamed-ali/thrust,xiongzhanblake/thrust,GrimDerp/thrust,GrimDerp/thrust,zhenglaizhang/thrust,thrust/thrust,egaburov/thrust,thvasilo/thrust,arnabgho/thrust,sarvex/thrust,xiongzhanblake/thrust_src,andrewcorrigan/thrust-multi-permutation-iterator,egaburov/thru...
testing/backend/cuda/find.cu
testing/backend/cuda/find.cu
#include <unittest/unittest.h> #include <thrust/find.h> #include <thrust/execution_policy.h> template<typename T> struct equal_to_value_pred { T value; equal_to_value_pred(T value) : value(value) {} __host__ __device__ bool operator()(T v) const { return v == value; } }; template<typename T> struc...
apache-2.0
Cuda
a0edc24cce292e038cc3b6ee6d78fca8e39e9f7a
add host code for pnpoly example
benvanwerkhoven/kernel_tuner
examples/cuda/pnpoly_host.cu
examples/cuda/pnpoly_host.cu
#include <stdio.h> #include <cuda.h> #include "pnpoly.cu" #ifndef grid_size_x #define grid_size_x 1 #endif #ifndef grid_size_y #define grid_size_y 1 #endif /* * This function contains the host code for benchmarking the cn_pnpoly CUDA kernel * Including the time spent on data transfers between host and devi...
apache-2.0
Cuda
5c886430f69284c2e47eb63ebf30229077615e60
Add an example program demonstrating an implementation of Black-Scholes
egaburov/agency,egaburov/agency
examples/black_scholes.cu
examples/black_scholes.cu
#include <agency/agency.hpp> #include <agency/cuda.hpp> #include <vector> #include <math.h> #include <random> #include <chrono> #include <iostream> __host__ __device__ float cnd(float x) { static constexpr float sqrt2 = 1.41421356237; static constexpr float inv_sqrt2 = 1.f / sqrt2; return 0.5f * (1.f + erf(i...
bsd-3-clause
Cuda
1b106d5b2b0e7e0a108f8319bcd17fbe126047eb
Add deleted cuda_device.cu file.
odashi/primitiv,odashi/primitiv,odashi/primitiv
primitiv/cuda_device.cu
primitiv/cuda_device.cu
#include <primitiv/config.h> #include <random> #include <primitiv/cuda_device.h> #include <primitiv/internal/cuda_utils.h> #include <primitiv/error.h> namespace primitiv { namespace devices { std::uint32_t CUDA::num_devices() { int ret; CUDA_CALL(::cudaGetDeviceCount(&ret)); return ret; } void CUDA::assert_s...
apache-2.0
Cuda
e67019651a55ea09a21159701924518e673441d7
Add abs maximum search (the code sits in the wrong directory ATM).
SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC
MS3/Sketches/GCF_new/dbl_max.cu
MS3/Sketches/GCF_new/dbl_max.cu
#include "threadFenceReduction_kernel.cuh" struct doubleMax { TASKCFG double init() {return 0.0;} TASKCFG double reduce(double x, double acc){return x > acc ? x : acc;} TASKCFG double f(double c){return fabs(c);} }; extern "C" __global__ void max_512_e2(const double *g_idata, double *g_odata, unsigned int n) { ...
apache-2.0
Cuda
8025edab7993db113e7127505bc8108b66e26fdc
add gpu_util.cuh
daerduoCarey/SpatialTransformerLayer
include/caffe/gpu_util.cuh
include/caffe/gpu_util.cuh
#ifndef CAFFE_UTIL_GPU_UTIL_H_ #define CAFFE_UTIL_GPU_UTIL_H_ namespace caffe { template <typename Dtype> inline __device__ Dtype caffe_gpu_atomic_add(const Dtype val, Dtype* address); template <> inline __device__ float caffe_gpu_atomic_add(const float val, float* address) { return atomicAdd(address, val); } // ...
mit
Cuda
83f39966a5a3c0d228d78b5bf620a6d899166a90
Create dp4a.cu
gpu0/cuda-code,gpu0/cuda-code
dp4a/dp4a.cu
dp4a/dp4a.cu
#include<iostream> #include <stdio.h> #define ITER 1024*1024 #define SSZ 512 #define BSZ 7*4 #include <time.h> #include <sys/time.h> #define USECPSEC 1000000ULL unsigned long long dtime_usec(unsigned long long start){ timeval tv; gettimeofday(&tv, 0); return ((tv.tv_sec*USECPSEC)+tv.tv_usec)-start; } __glob...
bsd-3-clause
Cuda
27d90be45e6c7cc76556288c6dc867e8e4e74e39
Test scan_by_key algorithms with thrust::seq in __device__ code.
sarvex/thrust,sarvex/thrust,andrewcorrigan/thrust-multi-permutation-iterator,arnabgho/thrust,jaredhoberock/thrust,jaredhoberock/thrust,thrust/thrust,Ricardo666666/thrust,thvasilo/thrust,raygit/thrust,mohamed-ali/thrust,zhenglaizhang/thrust,thrust/thrust,arnabgho/thrust,raygit/thrust,zeryx/thrust,GrimDerp/thrust,dachzie...
testing/backend/cuda/scan_by_key.cu
testing/backend/cuda/scan_by_key.cu
#include <unittest/unittest.h> #include <thrust/scan.h> #include <thrust/functional.h> #include <thrust/execution_policy.h> template<typename Iterator1, typename Iterator2, typename Iterator3> __global__ void inclusive_scan_by_key_kernel(Iterator1 keys_first, Iterator1 keys_last, Iterator2 values_first, Iterator3 res...
apache-2.0
Cuda
6d1b0303bcf54585f2e6f0fd443f1aa056f40950
Fix stratify compilation
fciceri17/peo-pycuda
lib/stratify_none.cu
lib/stratify_none.cu
__global__ void stratify_none_getD(double *numbering, long long int *roots, int *indptr, int *indices, int n, float c, long long int root, float *D) { const int i = threadIdx.x; D[i] = 0; if(roots[i] != root) return; int d = 0; for(int j = indptr[i]; j < indptr[i+1]; j++){ if(roots[indices...
mit
Cuda
d5fd3422888a34ae18ff0c559e4e31c0cbdecc38
Test count & count_if with thrust::seq in __device__ code.
xiongzhanblake/thrust,xiongzhanblake/thrust_src,andrewcorrigan/thrust-multi-permutation-iterator,raygit/thrust,arnabgho/thrust,sdalton1/thrust,arnabgho/thrust,mohamed-ali/thrust,zeryx/thrust,thrust/thrust,egaburov/thrust,dachziegel/thrust,jaredhoberock/thrust,marksantos/thrust,thvasilo/thrust,thrust/thrust,egaburov/thr...
testing/backend/cuda/count.cu
testing/backend/cuda/count.cu
#include <unittest/unittest.h> #include <thrust/count.h> #include <thrust/execution_policy.h> template<typename Iterator, typename T, typename Iterator2> __global__ void count_kernel(Iterator first, Iterator last, T value, Iterator2 result) { *result = thrust::count(thrust::seq, first, last, value); } template<ty...
apache-2.0
Cuda
07908736fbd4f192cae49e8cad3667e385942d4b
Test is_sorted_until with thrust::seq in __device__ code.
xiongzhanblake/thrust,GrimDerp/thrust,xiongzhanblake/thrust,thrust/thrust,sarvex/thrust,Ricardo666666/thrust,thvasilo/thrust,sdalton1/thrust,zhenglaizhang/thrust,GrimDerp/thrust,xiongzhanblake/thrust_src,jaredhoberock/thrust,raygit/thrust,thvasilo/thrust,egaburov/thrust,jaredhoberock/thrust,marksantos/thrust,arnabgho/t...
testing/backend/cuda/is_sorted_until.cu
testing/backend/cuda/is_sorted_until.cu
#include <unittest/unittest.h> #include <thrust/sort.h> #include <thrust/execution_policy.h> template<typename Iterator1, typename Iterator2> __global__ void is_sorted_until_kernel(Iterator1 first, Iterator1 last, Iterator2 result) { *result = thrust::is_sorted_until(thrust::seq, first, last); } template<typename...
apache-2.0
Cuda
55c2e9739dd3cfc946692ef61697e4debead5759
Remove unnecessary intermediate data.
cupy/cupy,cupy/cupy,cupy/cupy,cupy/cupy
cupy/core/include/cupy/atomics.cuh
cupy/core/include/cupy/atomics.cuh
#pragma once #if __CUDA_ARCH__ < 600 __device__ double atomicAdd(double *address, double val) { unsigned long long int* address_as_ull = (unsigned long long int*)address; unsigned long long int old = *address_as_ull; unsigned long long int assumed; do { assumed = old; old = atomicCAS(address_as_ull,...
#pragma once #if __CUDA_ARCH__ < 600 __device__ double atomicAdd(double *address, double val) { unsigned long long int* address_as_ull = (unsigned long long int*)address; unsigned long long int old = *address_as_ull; unsigned long long int assumed; do { assumed = old; old = atomicCAS(address_as_ull,...
mit
Cuda
64af2941416ae03b09eb3ec0b9aa4f8b184174c9
Add simple_cuda_streams example.
jaredhoberock/thrust,arnabgho/thrust,arnabgho/thrust,sdalton1/thrust,xiongzhanblake/thrust,xiongzhanblake/thrust,thrust/thrust,thrust/thrust,GrimDerp/thrust,marksantos/thrust,xiongzhanblake/thrust_src,zeryx/thrust,andrewcorrigan/thrust-multi-permutation-iterator,zeryx/thrust,thrust/thrust,GrimDerp/thrust,thvasilo/thrus...
examples/cuda/simple_cuda_streams.cu
examples/cuda/simple_cuda_streams.cu
#include <iostream> #include <thrust/device_vector.h> #include <thrust/for_each.h> #include <thrust/system/cuda/execution_policy.h> #include <cstdio> #include <cassert> // This example demonstrates how to achieve asynchronous, concurrent algorithm execution using // the CUDA backend's low-level stream-based interface....
apache-2.0
Cuda
c8e52b3856182d0a796c384402d478a37b795ef4
Test minmax_element with thrust::seq in __device__ code.
jaredhoberock/thrust,marksantos/thrust,zhenglaizhang/thrust,arnabgho/thrust,thrust/thrust,egaburov/thrust,mohamed-ali/thrust,raygit/thrust,jaredhoberock/thrust,andrewcorrigan/thrust-multi-permutation-iterator,Ricardo666666/thrust,thrust/thrust,xiongzhanblake/thrust_src,Ricardo666666/thrust,raygit/thrust,arnabgho/thrust...
testing/backend/cuda/minmax_element.cu
testing/backend/cuda/minmax_element.cu
#include <unittest/unittest.h> #include <thrust/extrema.h> template<typename Iterator1, typename Iterator2> __global__ void minmax_element_kernel(Iterator1 first, Iterator1 last, Iterator2 result) { *result = thrust::minmax_element(thrust::seq, first, last); } template<typename Iterator1, typename Iterator2, type...
apache-2.0
Cuda
7356abb2535cace55724b6299c4b742bc2598c1e
add example 04_sqrt launching 128 sqrt kernels
rk0der/railgun,rk0der/railgun,rk0der/railgun
examples/04_sqrt/sqrt_128.cu
examples/04_sqrt/sqrt_128.cu
#include "railgun.h" #include <stdio.h> #include <cuda_runtime.h> __global__ void vector_sqrt(int n, const float *A, float *B) { int i, j; for (i = 0; i < n; i++) { // for (j = 0; j < 10; j++) { B[i] = sqrtf(A[i]); // } } } int main(void) { const int k = 128; int *lens, *sizes; float **ha, *...
mit
Cuda
b79facfff86bd1344eefce65be2c76bb0ea17a3e
Add Nathan's weld_vertices example
Ricardo666666/thrust,jaredhoberock/thrust,GrimDerp/thrust,sarvex/thrust,thvasilo/thrust,mohamed-ali/thrust,raygit/thrust,xiongzhanblake/thrust,jaredhoberock/thrust,GrimDerp/thrust,marksantos/thrust,egaburov/thrust,zeryx/thrust,egaburov/thrust,arnabgho/thrust,xiongzhanblake/thrust,zhenglaizhang/thrust,andrewcorrigan/thr...
examples/weld_vertices.cu
examples/weld_vertices.cu
#include <thrust/device_vector.h> #include <thrust/remove.h> #include <thrust/unique.h> #include <thrust/binary_search.h> #include <thrust/sort.h> #include <iostream> // This example "welds" triangle vertices together by taking as // input "triangle soup" and eliminating redundant vertex positions // and shared ed...
apache-2.0
Cuda
032ed8ab9a8c887efe44892900bee949355139f0
Test partition_point with thrust::seq in __device__ code.
thrust/thrust,jaredhoberock/thrust,dachziegel/thrust,GrimDerp/thrust,thrust/thrust,dachziegel/thrust,xiongzhanblake/thrust_src,mohamed-ali/thrust,mohamed-ali/thrust,xiongzhanblake/thrust,thvasilo/thrust,jaredhoberock/thrust,thrust/thrust,zeryx/thrust,sdalton1/thrust,zhenglaizhang/thrust,sarvex/thrust,egaburov/thrust,ra...
testing/backend/cuda/partition_point.cu
testing/backend/cuda/partition_point.cu
#include <unittest/unittest.h> #include <thrust/partition.h> #include <thrust/functional.h> #include <thrust/execution_policy.h> template<typename Iterator1, typename Predicate, typename Iterator2> __global__ void partition_point_kernel(Iterator1 first, Iterator1 last, Predicate pred, Iterator2 result) { *result = ...
apache-2.0
Cuda
e8cab6a94c1a7dc8070171254fdcd4ea6d60afe7
Add kernel for mean pool
spacy-io/thinc,explosion/thinc,explosion/thinc,explosion/thinc,spacy-io/thinc,explosion/thinc,spacy-io/thinc
include/_kernels.cu
include/_kernels.cu
#include <stdio.h> void __device__ saxpy(float* X, const float* Y, float scale, int n) { for (int i=0; i < n; ++i) // Iterate over cols X[i] += Y[i] * scale; } void __global__ kernel_add_one(int* a, int length) { int gid = threadIdx.x + blockDim.x*blockIdx.x; while(gid < length) { a[gid] +...
mit
Cuda
2e913ad46d34dd6eb37923064fdaf04449faa8d6
Add async_reduce example
GrimDerp/thrust,thrust/thrust,jaredhoberock/thrust,mohamed-ali/thrust,thvasilo/thrust,jaredhoberock/thrust,zeryx/thrust,thrust/thrust,thrust/thrust,sarvex/thrust,zhenglaizhang/thrust,marksantos/thrust,egaburov/thrust,xiongzhanblake/thrust_src,xiongzhanblake/thrust,dachziegel/thrust,GrimDerp/thrust,egaburov/thrust,thrus...
examples/cuda/async_reduce.cu
examples/cuda/async_reduce.cu
#include <thrust/device_vector.h> #include <thrust/reduce.h> #include <thrust/system/cuda/execution_policy.h> #include <cassert> #if __cplusplus >= 201103L #include <future> #endif // This example demonstrates two ways to achieve algorithm invocations that are asynchronous with // the calling thread. // // The first ...
apache-2.0
Cuda
c18f1c74f5b8b326b91ed34d90bddfa8ec82d7c1
Add tests for compiling CUDA files with -E.
llvm-mirror/clang,llvm-mirror/clang,llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,llvm-mirror/cl...
test/Preprocessor/cuda-preprocess.cu
test/Preprocessor/cuda-preprocess.cu
// Tests CUDA compilation with -E. // REQUIRES: clang-driver // REQUIRES: x86-registered-target // REQUIRES: nvptx-registered-target #ifndef __CUDA_ARCH__ #define PREPROCESSED_AWAY clang_unittest_no_arch PREPROCESSED_AWAY #else clang_unittest_cuda_arch __CUDA_ARCH__ #endif // CHECK-NOT: PREPROCESSED_AWAY // RUN: %c...
apache-2.0
Cuda
41202cdbb70eff9be94e4f5a4b801a8c5e26d599
Test merge with thrust::seq in __device__ code.
GrimDerp/thrust,mohamed-ali/thrust,marksantos/thrust,marksantos/thrust,dachziegel/thrust,arnabgho/thrust,arnabgho/thrust,raygit/thrust,jaredhoberock/thrust,andrewcorrigan/thrust-multi-permutation-iterator,andrewcorrigan/thrust-multi-permutation-iterator,thrust/thrust,zeryx/thrust,jaredhoberock/thrust,sarvex/thrust,Rica...
testing/backend/cuda/merge.cu
testing/backend/cuda/merge.cu
#include <unittest/unittest.h> #include <thrust/merge.h> #include <thrust/functional.h> #include <thrust/sort.h> #include <thrust/extrema.h> #include <thrust/execution_policy.h> template<typename Iterator1, typename Iterator2, typename Iterator3, typename Iterator4> __global__ void merge_kernel(Iterator1 first1, Iter...
apache-2.0
Cuda
41b98b642e360b570f2e51e91cbebe9068971806
Add Romein-like CUDA gridder (convolve only at the moment).
SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC
MS3/Sketches/CPU_Gridders/scatter_gridder.cu
MS3/Sketches/CPU_Gridders/scatter_gridder.cu
#include "scatter_gridder.h" __device__ double atomicAdd(double* address, double val) { #ifdef FAKE_ATOMIC double orig = *address; *address = orig + val; return orig; #else unsigned long long int* address_as_ull = (unsigned long long int*)address; unsigned long long int old = *address_as_ull, assumed; do {...
apache-2.0
Cuda
fdf6fe4e758d660d2b8dc1a60de911e7b8d41351
Fix DistKLDivCriterion gradInput formula
colesbury/cunn,apaszke/cunn,colesbury/cunn,apaszke/cunn,apaszke/cunn,colesbury/cunn
lib/THCUNN/DistKLDivCriterion.cu
lib/THCUNN/DistKLDivCriterion.cu
#include "THCUNN.h" #include "common.h" #include <thrust/fill.h> #include <thrust/functional.h> #include <thrust/device_ptr.h> #include <thrust/reduce.h> #include <thrust/inner_product.h> struct kl_functor { __host__ __device__ float operator()(const float& x, const float& y) const { return y > 0 ? y * (log...
#include "THCUNN.h" #include "common.h" #include <thrust/fill.h> #include <thrust/functional.h> #include <thrust/device_ptr.h> #include <thrust/reduce.h> #include <thrust/inner_product.h> struct kl_functor { __host__ __device__ float operator()(const float& x, const float& y) const { return y > 0 ? y * (log...
bsd-3-clause
Cuda
c460d1491b257ad39a905c8c0fbadf5a5ca0b598
Add Monte Carlo example.
jbrownbridge/thrust,jbrownbridge/thrust,jbrownbridge/thrust,jbrownbridge/thrust
examples/monte_carlo.cu
examples/monte_carlo.cu
#include <thrust/random/linear_congruential_engine.h> #include <thrust/iterator/counting_iterator.h> #include <thrust/transform_reduce.h> #include <iostream> // we could vary M & N to find the perf sweet spot struct estimate_pi { __host__ __device__ float operator()(unsigned int seed) { using namespace th...
apache-2.0
Cuda
b5bb3cad10846b344b64643f08aaf1bf5002be41
Add Week 4 files for list reduction
NikolayGenov/Heterogeneous-Parallel-Programming-Coursera
Week4_Computation_Patterns/improved_reduction.cu
Week4_Computation_Patterns/improved_reduction.cu
// MP Reduction // Given a list (lst) of length n // Output its sum = lst[0] + lst[1] + ... + lst[n-1]; #include <wb.h> #define BLOCK_SIZE 512 //@@ You can change this #define wbCheck(stmt) do { \ cudaError_t err = stmt; ...
mit
Cuda
3e6c0a402fe6ed159d51714d1e07e53dea19a260
Test min_element with thrust::seq in __device__ code.
thrust/thrust,sdalton1/thrust,marksantos/thrust,zhenglaizhang/thrust,thvasilo/thrust,raygit/thrust,thrust/thrust,arnabgho/thrust,raygit/thrust,mohamed-ali/thrust,zeryx/thrust,egaburov/thrust,andrewcorrigan/thrust-multi-permutation-iterator,jaredhoberock/thrust,zeryx/thrust,xiongzhanblake/thrust_src,GrimDerp/thrust,zhen...
testing/backend/cuda/min_element.cu
testing/backend/cuda/min_element.cu
#include <unittest/unittest.h> #include <thrust/extrema.h> #include <thrust/execution_policy.h> template<typename Iterator, typename Iterator2> __global__ void min_element_kernel(Iterator first, Iterator last, Iterator2 result) { *result = thrust::min_element(thrust::seq, first, last); } template<typename Iterato...
apache-2.0
Cuda
ba356c529dcd3d7389a7acbe984f640aa8e3eef1
Test mismatch with thrust::seq in __device__ code.
xiongzhanblake/thrust,raygit/thrust,marksantos/thrust,sarvex/thrust,xiongzhanblake/thrust,thrust/thrust,egaburov/thrust,mohamed-ali/thrust,Ricardo666666/thrust,arnabgho/thrust,zeryx/thrust,dachziegel/thrust,xiongzhanblake/thrust_src,xiongzhanblake/thrust_src,andrewcorrigan/thrust-multi-permutation-iterator,Ricardo66666...
testing/backend/cuda/mismatch.cu
testing/backend/cuda/mismatch.cu
#include <unittest/unittest.h> #include <thrust/mismatch.h> #include <thrust/execution_policy.h> template<typename Iterator1, typename Iterator2, typename Iterator3> __global__ void mismatch_kernel(Iterator1 first1, Iterator1 last1, Iterator2 first2, Iterator3 result) { *result = thrust::mismatch(thrust::seq, first...
apache-2.0
Cuda
33f88fe7a116165e8db1506fbb136e3d48cabf50
Add cudaRegister.cu lit test
GPUOpen-ProfessionalCompute-Tools/HIP,ROCm-Developer-Tools/HIP,ROCm-Developer-Tools/HIP,GPUOpen-ProfessionalCompute-Tools/HIP,GPUOpen-ProfessionalCompute-Tools/HIP,GPUOpen-ProfessionalCompute-Tools/HIP,ROCm-Developer-Tools/HIP,ROCm-Developer-Tools/HIP,GPUOpen-ProfessionalCompute-Tools/HIP,ROCm-Developer-Tools/HIP
tests/hipify-clang/cudaRegister.cu
tests/hipify-clang/cudaRegister.cu
// RUN: %run_test hipify "%s" "%t" %cuda_args /* Copyright (c) 2015-2016 Advanced Micro Devices, Inc. All rights reserved. Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, incl...
mit
Cuda
7511216454c46abf102502b90c96a276cc0f5228
Fix double-negative.
autofac/Autofac
src/Autofac/Core/Resolving/Pipeline/PipelineBuilderEnumerator.cs
src/Autofac/Core/Resolving/Pipeline/PipelineBuilderEnumerator.cs
// Copyright (c) Autofac Project. All rights reserved. // Licensed under the MIT License. See LICENSE in the project root for license information. using System; using System.Collections; using System.Collections.Generic; namespace Autofac.Core.Resolving.Pipeline { /// <summary> /// Enumerator for a pipeline ...
// Copyright (c) Autofac Project. All rights reserved. // Licensed under the MIT License. See LICENSE in the project root for license information. using System; using System.Collections; using System.Collections.Generic; namespace Autofac.Core.Resolving.Pipeline { /// <summary> /// Enumerator for a pipeline ...
mit
C#
8334a0f25bacfaceda39d50177d11a5452dcd195
Change authentication failed error message.
LykkeCity/CompetitionPlatform,LykkeCity/CompetitionPlatform,LykkeCity/CompetitionPlatform
src/CompetitionPlatform/Views/Shared/AuthenticationFailed.cshtml
src/CompetitionPlatform/Views/Shared/AuthenticationFailed.cshtml
@{ ViewData["Title"] = "Access Denied"; } <div class="container"> <h1 class="text-danger">Error.</h1> <h2 class="text-danger">Authentication Failed.</h2> <p> There was a remote failure during Authentication. </p> </div>
@{ ViewData["Title"] = "Access Denied"; } <div class="container"> <h1 class="text-danger">Error.</h1> <h2 class="text-danger">Authentication Failed.</h2> <p> You have denied Competition Platform access to your resources. </p> </div>
mit
C#
4e6c0004c1e506ede1aafab507218a844876efdd
rename sqlserver processor
dotnetcore/CAP,dotnetcore/CAP,dotnetcore/CAP,ouraspnet/cap
src/DotNetCore.CAP.SqlServer/CAP.SqlServerCapOptionsExtension.cs
src/DotNetCore.CAP.SqlServer/CAP.SqlServerCapOptionsExtension.cs
// Copyright (c) .NET Core Community. All rights reserved. // Licensed under the MIT License. See License.txt in the project root for license information. using System; using DotNetCore.CAP.Processor; using DotNetCore.CAP.SqlServer; using Microsoft.EntityFrameworkCore; using Microsoft.Extensions.DependencyInjection; ...
// Copyright (c) .NET Core Community. All rights reserved. // Licensed under the MIT License. See License.txt in the project root for license information. using System; using DotNetCore.CAP.Processor; using DotNetCore.CAP.SqlServer; using Microsoft.EntityFrameworkCore; using Microsoft.Extensions.DependencyInjection; ...
mit
C#
7eb974a2a3f834965f714b94ef954be190c68c25
add Schedule status
takenet/messaginghub-client-csharp
src/Takenet.MessagingHub.Client/Extensions/Scheduler/Schedule.cs
src/Takenet.MessagingHub.Client/Extensions/Scheduler/Schedule.cs
using System; using System.Runtime.Serialization; using Lime.Protocol; namespace Takenet.MessagingHub.Client.Extensions.Scheduler { [DataContract] public class Schedule : Document { public const string MIME_TYPE = "application/vnd.iris.schedule+json"; public static readonly MediaType Media...
using System; using System.Runtime.Serialization; using Lime.Protocol; namespace Takenet.MessagingHub.Client.Extensions.Scheduler { [DataContract] public class Schedule : Document { public const string MIME_TYPE = "application/vnd.iris.schedule+json"; public static readonly MediaType Media...
apache-2.0
C#
4bd7d4d7a5b74a1ffbff289c3416bbfd86df0020
tidy pressed mixin.
SuperJMN/Avalonia,jkoritzinsky/Avalonia,wieslawsoltes/Perspex,AvaloniaUI/Avalonia,Perspex/Perspex,AvaloniaUI/Avalonia,wieslawsoltes/Perspex,AvaloniaUI/Avalonia,SuperJMN/Avalonia,jkoritzinsky/Avalonia,akrisiun/Perspex,SuperJMN/Avalonia,AvaloniaUI/Avalonia,AvaloniaUI/Avalonia,wieslawsoltes/Perspex,SuperJMN/Avalonia,jkori...
src/Avalonia.Controls/Mixins/PressedMixin.cs
src/Avalonia.Controls/Mixins/PressedMixin.cs
using Avalonia.Interactivity; using Avalonia.Input; namespace Avalonia.Controls.Mixins { /// <summary> /// Adds pressed functionality to control classes. /// /// Adds the ':pressed' class when the item is pressed. /// </summary> public static class PressedMixin { /// <summary> ...
using Avalonia.Interactivity; using Avalonia.Input; namespace Avalonia.Controls.Mixins { /// <summary> /// Adds pressed functionality to control classes. /// /// Adds the ':pressed' class when the item is pressed. /// </summary> public static class PressedMixin { private static vo...
mit
C#
aabdd69ef74fe1bac98ceb73b1230d9271690aa2
Implement Parse and WriteTo for SkyboxSettings
feliwir/openSage,feliwir/openSage
src/OpenSage.Game/Data/Map/SkyboxSettings.cs
src/OpenSage.Game/Data/Map/SkyboxSettings.cs
using System.IO; using System.Numerics; using OpenSage.FileFormats; namespace OpenSage.Data.Map { public sealed class SkyboxSettings : Asset { public const string AssetName = "SkyboxSettings"; public Vector3 Position { get; private set; } public float Scale { get; private set; } ...
using System.IO; namespace OpenSage.Data.Map { public sealed class SkyboxSettings : Asset { public const string AssetName = "SkyboxSettings"; public byte[] Unknown { get; private set; } internal static SkyboxSettings Parse(BinaryReader reader, MapParseContext context) { ...
mit
C#
b8333505bb5baed270487805d140023e58deaad9
enable skipping
NickCraver/StackExchange.Exceptional,NickCraver/StackExchange.Exceptional
tests/StackExchange.Exceptional.Tests/Storage/MongoDBErrorStoreTest.cs
tests/StackExchange.Exceptional.Tests/Storage/MongoDBErrorStoreTest.cs
using System; using System.Runtime.CompilerServices; using MongoDB.Driver; using StackExchange.Exceptional.Stores; using Xunit; using Xunit.Abstractions; namespace StackExchange.Exceptional.Tests.Storage { public class MongoDBErrorStoreTest : StoreBaseTest, IClassFixture<MongoDBFixture> { public strin...
using System; using System.Runtime.CompilerServices; using MongoDB.Driver; using StackExchange.Exceptional.Stores; using Xunit; using Xunit.Abstractions; namespace StackExchange.Exceptional.Tests.Storage { public class MongoDBErrorStoreTest : StoreBaseTest, IClassFixture<MongoDBFixture> { private Mong...
apache-2.0
C#
f8d53a1e30b2f3471ac7712983dc8af703a79272
Fix variable mismatch
ppy/osu,smoogipoo/osu,UselessToucan/osu,peppy/osu-new,peppy/osu,smoogipoo/osu,UselessToucan/osu,ppy/osu,EVAST9919/osu,NeoAdonis/osu,2yangk23/osu,NeoAdonis/osu,johnneijzen/osu,ppy/osu,UselessToucan/osu,EVAST9919/osu,peppy/osu,peppy/osu,2yangk23/osu,ZLima12/osu,ZLima12/osu,NeoAdonis/osu,smoogipoo/osu,smoogipooo/osu,johnn...
build/build.cake
build/build.cake
#addin "nuget:?package=CodeFileSanity&version=0.0.21" #addin "nuget:?package=JetBrains.ReSharper.CommandLineTools&version=2018.2.2" #tool "nuget:?package=NVika.MSBuild&version=1.0.1" var nVikaToolPath = GetFiles("./tools/NVika.MSBuild.*/tools/NVika.exe").First(); ///////////////////////////////////////////////////////...
#addin "nuget:?package=CodeFileSanity&version=0.0.21" #addin "nuget:?package=JetBrains.ReSharper.CommandLineTools&version=2018.2.2" #tool "nuget:?package=NVika.MSBuild&version=1.0.1" var nVikaToolPath = GetFiles("./tools/NVika.MSBuild.*/tools/NVika.exe").First(); ///////////////////////////////////////////////////////...
mit
C#
8e12a1c3b33aafef75a60c491f830bee2617b675
add logic to populate set count per year when synchronizing themes
zmira/abremir.AllMyBricks
abremir.AllMyBricks.DataSynchronizer/Synchronizers/ThemeSynchronizer.cs
abremir.AllMyBricks.DataSynchronizer/Synchronizers/ThemeSynchronizer.cs
using abremir.AllMyBricks.Data.Interfaces; using abremir.AllMyBricks.Data.Models; using abremir.AllMyBricks.DataSynchronizer.Interfaces; using abremir.AllMyBricks.ThirdParty.Brickset.Interfaces; using abremir.AllMyBricks.ThirdParty.Brickset.Models; using System.Collections.Generic; namespace abremir.AllMyBricks.DataS...
using abremir.AllMyBricks.Data.Interfaces; using abremir.AllMyBricks.Data.Models; using abremir.AllMyBricks.DataSynchronizer.Interfaces; using abremir.AllMyBricks.ThirdParty.Brickset.Interfaces; using abremir.AllMyBricks.ThirdParty.Brickset.Models; using System.Collections.Generic; namespace abremir.AllMyBricks.DataS...
mit
C#
45b803ce411b5ba25c7b14052463877853009559
Simplify Healing Component deletion.
space-wizards/space-station-14,space-wizards/space-station-14,space-wizards/space-station-14,space-wizards/space-station-14,space-wizards/space-station-14-content,space-wizards/space-station-14-content,space-wizards/space-station-14-content,space-wizards/space-station-14,space-wizards/space-station-14
Content.Server/GameObjects/Components/Healing/HealingComponent.cs
Content.Server/GameObjects/Components/Healing/HealingComponent.cs
using System; using SS14.Shared.GameObjects; using Content.Server.GameObjects.EntitySystems; using SS14.Shared.Interfaces.GameObjects; using SS14.Shared.Map; using SS14.Shared.IoC; using SS14.Server.GameObjects; using SS14.Shared.Maths; using SS14.Server.Interfaces.GameObjects; using SS14.Shared.Interfaces.Timing; usi...
using System; using SS14.Shared.GameObjects; using Content.Server.GameObjects.EntitySystems; using SS14.Shared.Interfaces.GameObjects; using SS14.Shared.Map; using SS14.Shared.IoC; using SS14.Server.GameObjects; using SS14.Shared.Maths; using SS14.Server.Interfaces.GameObjects; using SS14.Shared.Interfaces.Timing; usi...
mit
C#
18cd832be40a7b8e89e7c037e87958eb419dbe83
Add cancel token variant for FromMethod
modesttree/Zenject,modesttree/Zenject,modesttree/Zenject
UnityProject/Assets/Plugins/Zenject/OptionalExtras/Async/Runtime/Binders/AsyncFromBinderGeneric.cs
UnityProject/Assets/Plugins/Zenject/OptionalExtras/Async/Runtime/Binders/AsyncFromBinderGeneric.cs
using System; using System.Threading; using System.Threading.Tasks; namespace Zenject { [NoReflectionBaking] public class AsyncFromBinderGeneric<TContract, TConcrete> : AsyncFromBinderBase where TConcrete : TContract { public AsyncFromBinderGeneric( DiContainer container, BindInfo bind...
using System; using System.Threading.Tasks; #if EXTENJECT_INCLUDE_ADDRESSABLE_BINDINGS using UnityEngine.ResourceManagement.AsyncOperations; using UnityEngine.AddressableAssets; #endif namespace Zenject { [NoReflectionBaking] public class AsyncFromBinderGeneric<TContract, TConcrete> : AsyncFromBinderBase wher...
mit
C#
0a7220718461141d1ba4558909254d9cc2e2260b
Fix for three bugs in three lines.
jhinder/db-ticket
netfx-cs/db-pdftest/Program.cs
netfx-cs/db-pdftest/Program.cs
using System; using System.Collections.Generic; using System.Linq; using System.Text; using System.Threading.Tasks; using dbticket; namespace db_pdftest { class Program { static void Main(string[] args) { if (args.Length < 1) { Console.WriteLine("Invalid...
using System; using System.Collections.Generic; using System.Linq; using System.Text; using System.Threading.Tasks; using dbticket; namespace db_pdftest { class Program { static void Main(string[] args) { if (args.Length < 2) { Console.WriteLine("Invalid...
mit
C#
fd4a2e03b9ad48619a91582d558a1d7fd8f3af34
Address feedback
mazong1123/corefx,JosephTremoulet/corefx,JosephTremoulet/corefx,krytarowski/corefx,ericstj/corefx,BrennanConroy/corefx,JosephTremoulet/corefx,zhenlan/corefx,rjxby/corefx,ravimeda/corefx,nbarbettini/corefx,mmitche/corefx,nbarbettini/corefx,cydhaselton/corefx,krytarowski/corefx,rahku/corefx,gkhanna79/corefx,dotnet-bot/co...
src/System.Threading.AccessControl/tests/ThreadingAclExtensionsTests.cs
src/System.Threading.AccessControl/tests/ThreadingAclExtensionsTests.cs
// Licensed to the .NET Foundation under one or more agreements. // The .NET Foundation licenses this file to you under the MIT license. // See the LICENSE file in the project root for more information. using System.Security.AccessControl; using Xunit; namespace System.Threading.Tests { public static class Thread...
// Licensed to the .NET Foundation under one or more agreements. // The .NET Foundation licenses this file to you under the MIT license. // See the LICENSE file in the project root for more information. using System.Security.AccessControl; using Xunit; namespace System.Threading.Tests { public static class Thread...
mit
C#
0efe90338c7f8bc83620b046e0dbb7d2ab0eda67
Fix cast exceptions
mono/SkiaSharp,mono/SkiaSharp,mono/SkiaSharp,mono/SkiaSharp,mono/SkiaSharp,mono/SkiaSharp,mono/SkiaSharp
source/SkiaSharp.Views/SkiaSharp.Views.Mac/SKGLView.cs
source/SkiaSharp.Views/SkiaSharp.Views.Mac/SKGLView.cs
using System; using System.ComponentModel; using AppKit; using CoreGraphics; using Foundation; using SkiaSharp.Views.GlesInterop; namespace SkiaSharp.Views.Mac { [Register(nameof(SKGLView))] [DesignTimeVisible(true)] public class SKGLView : NSOpenGLView { private GRContext context; private GRBackendRenderTarge...
using System; using System.ComponentModel; using AppKit; using CoreGraphics; using Foundation; using SkiaSharp.Views.GlesInterop; namespace SkiaSharp.Views.Mac { [Register(nameof(SKGLView))] [DesignTimeVisible(true)] public class SKGLView : NSOpenGLView { private GRContext context; private GRBackendRenderTarge...
mit
C#
2e84efd6fa4aa81614360d7e8170b10e547d839e
Remove workaround for microsoft/nodejstools#2138
mgoertz-msft/roslyn,gafter/roslyn,davkean/roslyn,aelij/roslyn,KirillOsenkov/roslyn,mgoertz-msft/roslyn,ErikSchierboom/roslyn,AmadeusW/roslyn,gafter/roslyn,mgoertz-msft/roslyn,sharwell/roslyn,shyamnamboodiripad/roslyn,dotnet/roslyn,AlekseyTs/roslyn,heejaechang/roslyn,mavasani/roslyn,CyrusNajmabadi/roslyn,shyamnamboodiri...
src/VisualStudio/IntegrationTest/TestSetup/TestExtensionErrorHandler.cs
src/VisualStudio/IntegrationTest/TestSetup/TestExtensionErrorHandler.cs
// Licensed to the .NET Foundation under one or more agreements. // The .NET Foundation licenses this file to you under the MIT license. // See the LICENSE file in the project root for more information. using System; using System.Composition; using Microsoft.CodeAnalysis.ErrorReporting; using Microsoft.CodeAnalysis.H...
// Licensed to the .NET Foundation under one or more agreements. // The .NET Foundation licenses this file to you under the MIT license. // See the LICENSE file in the project root for more information. using System; using System.Composition; using Microsoft.CodeAnalysis.ErrorReporting; using Microsoft.CodeAnalysis.H...
mit
C#
8aff48abb9ddccf7aaa6d1736164eace955076b4
remove unnecessary qualification
shyamnamboodiripad/roslyn,dotnet/roslyn,CyrusNajmabadi/roslyn,mavasani/roslyn,dotnet/roslyn,shyamnamboodiripad/roslyn,shyamnamboodiripad/roslyn,mavasani/roslyn,CyrusNajmabadi/roslyn,mavasani/roslyn,CyrusNajmabadi/roslyn,dotnet/roslyn
src/Workspaces/Remote/ServiceHub/Host/RemoteWorkspace.PinnedSolution.cs
src/Workspaces/Remote/ServiceHub/Host/RemoteWorkspace.PinnedSolution.cs
// Licensed to the .NET Foundation under one or more agreements. // The .NET Foundation licenses this file to you under the MIT license. // See the LICENSE file in the project root for more information. using System; using System.Threading; using System.Threading.Tasks; namespace Microsoft.CodeAnalysis.Remote { ...
// Licensed to the .NET Foundation under one or more agreements. // The .NET Foundation licenses this file to you under the MIT license. // See the LICENSE file in the project root for more information. using System; using System.Threading; using System.Threading.Tasks; namespace Microsoft.CodeAnalysis.Remote { ...
mit
C#
5d3e82f37a7411c72bb84e063aa9e34f34baa8ae
Disable MVC Response Header
tommcclean/PortalCMS,tommcclean/PortalCMS,tommcclean/PortalCMS
Portal.CMS.Web/Global.asax.cs
Portal.CMS.Web/Global.asax.cs
using Portal.CMS.Web.Architecture.ViewEngines; using System.Web.Mvc; using System.Web.Optimization; using System.Web.Razor; using System.Web.Routing; using System.Web.WebPages; namespace Portal.CMS.Web { public class MvcApplication : System.Web.HttpApplication { protected void Application_Start() ...
using Portal.CMS.Web.Architecture.ViewEngines; using System.Web.Mvc; using System.Web.Optimization; using System.Web.Razor; using System.Web.Routing; using System.Web.WebPages; namespace Portal.CMS.Web { public class MvcApplication : System.Web.HttpApplication { protected void Application_Start() ...
mit
C#
957ec1807c5fb0b0282298e4f971325bd3661a8d
Fix issue "Unexpected RegexStringValidator failure in Configuration Property"
steentottrup/AspNet.Identity.MongoDB
src/AspNet.Identity.MongoDB/MongoDBIdentitySettings.cs
src/AspNet.Identity.MongoDB/MongoDBIdentitySettings.cs
using System; using System.Configuration; namespace AspNet.Identity.MongoDB { public class MongoDBIdentitySettings : ConfigurationSection { private static MongoDBIdentitySettings settings = ConfigurationManager.GetSection("mongoDBIdentitySettings") as MongoDBIdentitySettings; private const String userC...
using System; using System.Configuration; namespace AspNet.Identity.MongoDB { public class MongoDBIdentitySettings : ConfigurationSection { private static MongoDBIdentitySettings settings = ConfigurationManager.GetSection("mongoDBIdentitySettings") as MongoDBIdentitySettings; private const String userC...
mit
C#
047c57f6255ca42222bebe8a324b14f1466983ec
make stats-collected as event (verb in past tense not a noun)
msbahrul/EventStore,ianbattersby/EventStore,ianbattersby/EventStore,msbahrul/EventStore,ianbattersby/EventStore,ianbattersby/EventStore,msbahrul/EventStore,ianbattersby/EventStore,msbahrul/EventStore,msbahrul/EventStore,msbahrul/EventStore
src/EventStore/EventStore.Core/Services/SystemNames.cs
src/EventStore/EventStore.Core/Services/SystemNames.cs
// Copyright (c) 2012, Event Store LLP // All rights reserved. // // Redistribution and use in source and binary forms, with or without // modification, are permitted provided that the following conditions are // met: // // Redistributions of source code must retain the above copyright notice, // this list of cond...
// Copyright (c) 2012, Event Store LLP // All rights reserved. // // Redistribution and use in source and binary forms, with or without // modification, are permitted provided that the following conditions are // met: // // Redistributions of source code must retain the above copyright notice, // this list of cond...
bsd-3-clause
C#
456925d4dde40511c568a15857b174326433c35e
Address AssemblyVersion issue as suggested.
shahabhijeet/azure-sdk-for-net,hyonholee/azure-sdk-for-net,AsrOneSdk/azure-sdk-for-net,stankovski/azure-sdk-for-net,brjohnstmsft/azure-sdk-for-net,stankovski/azure-sdk-for-net,ayeletshpigelman/azure-sdk-for-net,yugangw-msft/azure-sdk-for-net,jamestao/azure-sdk-for-net,jamestao/azure-sdk-for-net,pilor/azure-sdk-for-net,...
src/SDKs/CognitiveServices/dataPlane/Vision/ComputerVision/ComputerVision/Properties/AssemblyInfo.cs
src/SDKs/CognitiveServices/dataPlane/Vision/ComputerVision/ComputerVision/Properties/AssemblyInfo.cs
// Copyright (c) Microsoft Corporation. All rights reserved. // Licensed under the MIT License. See License.txt in the project root for license information. using System.Reflection; using System.Resources; [assembly: AssemblyTitle("Microsoft Cognitive Services ComputerVision SDK")] [assembly: AssemblyDescription("Pro...
// Copyright (c) Microsoft Corporation. All rights reserved. // Licensed under the MIT License. See License.txt in the project root for license information. using System.Reflection; using System.Resources; [assembly: AssemblyTitle("Microsoft Cognitive Services ComputerVision SDK")] [assembly: AssemblyDescription("Pro...
mit
C#
4c18a67268d6aae90ed25c35d2f44fb7e5318cbe
add test step
smoogipooo/osu,ppy/osu,NeoAdonis/osu,smoogipoo/osu,johnneijzen/osu,ppy/osu,smoogipoo/osu,2yangk23/osu,johnneijzen/osu,NeoAdonis/osu,NeoAdonis/osu,peppy/osu,smoogipoo/osu,UselessToucan/osu,UselessToucan/osu,EVAST9919/osu,peppy/osu,UselessToucan/osu,peppy/osu,peppy/osu-new,ppy/osu,2yangk23/osu,EVAST9919/osu
osu.Game.Tests/Visual/UserInterface/TestSceneModButton.cs
osu.Game.Tests/Visual/UserInterface/TestSceneModButton.cs
// Copyright (c) ppy Pty Ltd <contact@ppy.sh>. Licensed under the MIT Licence. // See the LICENCE file in the repository root for full licence text. using osu.Framework.Graphics; using osu.Framework.Graphics.Sprites; using osu.Game.Overlays.Mods; using osu.Game.Rulesets.Mods; namespace osu.Game.Tests.Visual.UserInter...
// Copyright (c) ppy Pty Ltd <contact@ppy.sh>. Licensed under the MIT Licence. // See the LICENCE file in the repository root for full licence text. using NUnit.Framework; using osu.Framework.Graphics; using osu.Framework.Graphics.Sprites; using osu.Game.Overlays.Mods; using osu.Game.Rulesets.Mods; namespace osu.Game...
mit
C#
fd38e0a25df5488a97ba556407470bc7ed9fe6cb
Fix issue related to task execution Website-Create.
SharpeRAD/Cake.IIS
test/build.cake
test/build.cake
#addin "Cake.IIS" ////////////////////////////////////////////////////////////////////// // ARGUMENTS ////////////////////////////////////////////////////////////////////// var target = Argument("target", "Default"); var configuration = Argument("configuration", "Release"); //////////////////////////////////////...
#addin "Cake.IIS" ////////////////////////////////////////////////////////////////////// // ARGUMENTS ////////////////////////////////////////////////////////////////////// var target = Argument("target", "Default"); var configuration = Argument("configuration", "Release"); //////////////////////////////////////...
mit
C#
68f7140c84a58e9c0f20bec2ef1e76638ea75cc6
Add upper and lower limitation.
CountrySideEngineer/Ev3Controller
dev/src/Ev3Controller/ViewModel/Ev3MotorSteerViewModel.cs
dev/src/Ev3Controller/ViewModel/Ev3MotorSteerViewModel.cs
using System; using System.Collections.Generic; using System.Linq; using System.Text; using System.Threading.Tasks; namespace Ev3Controller.ViewModel { public class Ev3MotorSteerViewModel : ViewModelBase { #region public Ev3MotorSteerViewModel() { this.TargetMo...
using System; using System.Collections.Generic; using System.Linq; using System.Text; using System.Threading.Tasks; namespace Ev3Controller.ViewModel { public class Ev3MotorSteerViewModel : ViewModelBase { #region public Ev3MotorSteerViewModel() { this.TargetMo...
mit
C#
0af5e34898b51f7a5abdf4a9b835687235fec932
Fix issue with yield in function calls * yield x(yield y());
SirTony/Mond,Rohansi/Mond,SirTony/Mond,SirTony/Mond,Rohansi/Mond,Rohansi/Mond
Mond/Compiler/Expressions/Statements/YieldExpression.cs
Mond/Compiler/Expressions/Statements/YieldExpression.cs
namespace Mond.Compiler.Expressions.Statements { class YieldExpression : Expression, IStatementExpression { public Expression Value { get; private set; } public YieldExpression(Token token, Expression value) : base(token.FileName, token.Line, token.Column) { Val...
namespace Mond.Compiler.Expressions.Statements { class YieldExpression : Expression, IStatementExpression { public Expression Value { get; private set; } public YieldExpression(Token token, Expression value) : base(token.FileName, token.Line, token.Column) { Val...
mit
C#
58c344c79a9d3415c8196c91f5a4b13ff9660b16
Add NancyDashboardPassword setting used to enable dashboard
ritterim/silverpop-dotnet-api
samples/Silverpop.Client.WebTester/Infrastructure/CustomBootstrapper.cs
samples/Silverpop.Client.WebTester/Infrastructure/CustomBootstrapper.cs
using Microsoft.Extensions.Configuration; using Nancy; using Nancy.Configuration; using Nancy.Diagnostics; using Nancy.TinyIoc; namespace Silverpop.Client.WebTester.Infrastructure { public class CustomBootstrapper : DefaultNancyBootstrapper { public CustomBootstrapper() { var build...
using Microsoft.Extensions.Configuration; using Nancy; using Nancy.TinyIoc; namespace Silverpop.Client.WebTester.Infrastructure { public class CustomBootstrapper : DefaultNancyBootstrapper { public CustomBootstrapper() { var builder = new ConfigurationBuilder() .Set...
mit
C#
9fdd1cc98a486b710a55e404a69872653e14fd59
Test with using a better HardlineBreakInline parser to speed up processing
lunet-io/markdig,christophano/markdig
src/Textamina.Markdig/Syntax/Inlines/HardlineBreakInline.cs
src/Textamina.Markdig/Syntax/Inlines/HardlineBreakInline.cs
using Textamina.Markdig.Helpers; using Textamina.Markdig.Parsing; namespace Textamina.Markdig.Syntax { public class HardlineBreakInline : LeafInline { public static readonly InlineParser Parser = new ParserInternal(); private class ParserInternal : InlineParser { public Par...
using Textamina.Markdig.Helpers; using Textamina.Markdig.Parsing; namespace Textamina.Markdig.Syntax { public class HardlineBreakInline : LeafInline { public static readonly InlineParser Parser = new ParserInternal(); private class ParserInternal : InlineParser { public ove...
bsd-2-clause
C#
7c96bafc19a4d5851678045c42086b6aa3899e6f
Fix a few for WebSocketException.cs
TabbedOut/websocket-sharp,zq513705971/WebSocketApp,pjc0247/websocket-sharp-unity,prepare/websocket-sharp,sta/websocket-sharp,sinha-abhishek/websocket-sharp,jogibear9988/websocket-sharp,jmptrader/websocket-sharp,zq513705971/WebSocketApp,zhangwei900808/websocket-sharp,microdee/websocket-sharp,Liryna/websocket-sharp,2Toad...
websocket-sharp/WebSocketException.cs
websocket-sharp/WebSocketException.cs
#region License /* * WebSocketException.cs * * The MIT License * * Copyright (c) 2012-2014 sta.blockhead * * Permission is hereby granted, free of charge, to any person obtaining a copy * of this software and associated documentation files (the "Software"), to deal * in the Software without restriction, includ...
#region License /* * WebSocketException.cs * * The MIT License * * Copyright (c) 2012-2014 sta.blockhead * * Permission is hereby granted, free of charge, to any person obtaining a copy * of this software and associated documentation files (the "Software"), to deal * in the Software without restriction, includ...
mit
C#
76421884283fe5ecb242cec41b2aa383fd8a3104
Fix merge
joehmchan/elasticsearch-net,DavidSSL/elasticsearch-net,amyzheng424/elasticsearch-net,SeanKilleen/elasticsearch-net,RossLieberman/NEST,UdiBen/elasticsearch-net,tkirill/elasticsearch-net,robrich/elasticsearch-net,KodrAus/elasticsearch-net,Grastveit/NEST,ststeiger/elasticsearch-net,mac2000/elasticsearch-net,TheFireCookie/...
src/Tests/Nest.Tests.Unit/ObjectInitializer/Update/UpdateRequestTests.cs
src/Tests/Nest.Tests.Unit/ObjectInitializer/Update/UpdateRequestTests.cs
using Elasticsearch.Net; using FluentAssertions; using Nest.Tests.MockData.Domain; using NUnit.Framework; using System; using System.Collections.Generic; using System.Linq; using System.Reflection; using System.Text; using System.Threading.Tasks; namespace Nest.Tests.Unit.ObjectInitializer.Update { public class Upda...
using Elasticsearch.Net; using FluentAssertions; using Nest.Tests.MockData.Domain; using NUnit.Framework; using System; using System.Collections.Generic; using System.Linq; using System.Reflection; using System.Text; using System.Threading.Tasks; namespace Nest.Tests.Unit.ObjectInitializer.Update { public class Upda...
apache-2.0
C#
6d16db9310911d06ad9be139bf02f32c6452298e
Update FocusControlAction.cs
XamlBehaviors/XamlBehaviors,XamlBehaviors/XamlBehaviors,wieslawsoltes/AvaloniaBehaviors,wieslawsoltes/AvaloniaBehaviors
src/Avalonia.Xaml.Interactions/Core/FocusControlAction.cs
src/Avalonia.Xaml.Interactions/Core/FocusControlAction.cs
// Copyright (c) Wiesław Šoltés. All rights reserved. // Licensed under the MIT license. See LICENSE file in the project root for full license information. using Avalonia; using Avalonia.Controls; using Avalonia.Xaml.Interactivity; namespace Avalonia.Xaml.Interactions.Core { /// <summary> /// Focuses the ass...
// Copyright (c) Wiesław Šoltés. All rights reserved. // Licensed under the MIT license. See LICENSE file in the project root for full license information. using Avalonia; using Avalonia.Controls; using Avalonia.Xaml.Interactivity; namespace Avalonia.Xaml.Interactions.Core { /// <summary> /// Focuses the ass...
mit
C#
757b2fc5b11fc58c126dd0a3f8a4382db993e17d
Add overloads for configuring options when adding services
KevinDockx/HttpCacheHeaders
src/Marvin.Cache.Headers/Extensions/ServicesExtensions.cs
src/Marvin.Cache.Headers/Extensions/ServicesExtensions.cs
// Any comments, input: @KevinDockx // Any issues, requests: https://github.com/KevinDockx/HttpCacheHeaders using Marvin.Cache.Headers; using Marvin.Cache.Headers.Interfaces; using Marvin.Cache.Headers.Stores; using Microsoft.Extensions.DependencyInjection; using System; namespace Microsoft.Extensions.DependencyInje...
// Any comments, input: @KevinDockx // Any issues, requests: https://github.com/KevinDockx/HttpCacheHeaders using Marvin.Cache.Headers; using Marvin.Cache.Headers.Interfaces; using Marvin.Cache.Headers.Stores; using Microsoft.Extensions.DependencyInjection; using System; namespace Microsoft.Extensions.DependencyInje...
mit
C#
389e3c0052ccda9d489f19dd09a8396529dcd11e
make it green,just a boolean
ZA-PT/Obsidian,ZA-PT/Obsidian,ZA-PT/Obsidian,ZA-PT/Obsidian
src/Obsidian.Application/UserManagement/CreateUserSaga.cs
src/Obsidian.Application/UserManagement/CreateUserSaga.cs
using Obsidian.Application.ProcessManagement; using Obsidian.Domain; using Obsidian.Domain.Repositories; using System; using System.Collections.Generic; using System.Linq; using System.Threading.Tasks; namespace Obsidian.Application.UserManagement { public class CreateUserSaga : Saga, IStartsWith<CreateUserComman...
using Obsidian.Application.ProcessManagement; using Obsidian.Domain; using Obsidian.Domain.Repositories; using System; using System.Collections.Generic; using System.Linq; using System.Threading.Tasks; namespace Obsidian.Application.UserManagement { public class CreateUserSaga : Saga, IStartsWith<CreateUserComman...
apache-2.0
C#
cfaeb79a0c76c7c72e16c7cf635064fd489fac9c
Fix the name of DLL in DllImport.
kyulee1/corert,manu-silicon/corert,mjp41/corert,schellap/corert,gregkalapos/corert,sandreenko/corert,botaberg/corert,schellap/corert,gregkalapos/corert,krytarowski/corert,kyulee1/corert,manu-silicon/corert,manu-silicon/corert,gregkalapos/corert,schellap/corert,tijoytom/corert,botaberg/corert,mjp41/corert,yizhang82/core...
src/Common/src/Interop/Windows/mincore/Interop.Console.cs
src/Common/src/Interop/Windows/mincore/Interop.Console.cs
// Copyright (c) Microsoft. All rights reserved. // Licensed under the MIT license. See LICENSE file in the project root for full license information. using System; using System.Runtime.CompilerServices; using System.Runtime.InteropServices; internal static partial class Interop { private static class Libraries ...
// Copyright (c) Microsoft. All rights reserved. // Licensed under the MIT license. See LICENSE file in the project root for full license information. using System; using System.Runtime.CompilerServices; using System.Runtime.InteropServices; internal static partial class Interop { private static class Libraries ...
mit
C#
79a1d7b2b39d018b231abc2508ab1c1494acd39d
simplify CreateEmphasisedSpriteText
NeoAdonis/osu,UselessToucan/osu,ppy/osu,UselessToucan/osu,ppy/osu,smoogipoo/osu,peppy/osu-new,peppy/osu,smoogipooo/osu,peppy/osu,NeoAdonis/osu,smoogipoo/osu,peppy/osu,UselessToucan/osu,NeoAdonis/osu,ppy/osu,smoogipoo/osu
osu.Game/Graphics/Containers/Markdown/OsuMarkdownTextFlowContainer.cs
osu.Game/Graphics/Containers/Markdown/OsuMarkdownTextFlowContainer.cs
// Copyright (c) ppy Pty Ltd <contact@ppy.sh>. Licensed under the MIT Licence. // See the LICENCE file in the repository root for full licence text. using Markdig.Syntax.Inlines; using osu.Framework.Allocation; using osu.Framework.Graphics; using osu.Framework.Graphics.Containers.Markdown; using osu.Framework.Graphics...
// Copyright (c) ppy Pty Ltd <contact@ppy.sh>. Licensed under the MIT Licence. // See the LICENCE file in the repository root for full licence text. using Markdig.Syntax.Inlines; using osu.Framework.Allocation; using osu.Framework.Graphics.Containers.Markdown; using osu.Framework.Graphics.Sprites; using osu.Game.Graph...
mit
C#
e83f08eb7824083532530b83bb22b82985460f2b
Add xml docs to collection operations.
kangkot/ArangoDB-NET,yojimbo87/ArangoDB-NET
src/Arango/Arango.Client/API/Collections/ArangoCollectionOperation.cs
src/Arango/Arango.Client/API/Collections/ArangoCollectionOperation.cs
using Arango.Client.Protocol; namespace Arango.Client { public class ArangoCollectionOperation { private CollectionOperation _collectionOperation; internal ArangoCollectionOperation(CollectionOperation collectionOperation) { _collectionOperation = collectionOpera...
using Arango.Client.Protocol; namespace Arango.Client { public class ArangoCollectionOperation { private CollectionOperation _collectionOperation; internal ArangoCollectionOperation(CollectionOperation collectionOperation) { _collectionOperation = collectionOpera...
mit
C#
14e3b57699b7267c52f83782959cd881bae429de
adjust Serilog sink for new proto def
sascha-andres/go-logsink,sascha-andres/go-logsink,sascha-andres/go-logsink,sascha-andres/go-logsink,sascha-andres/go-logsink,sascha-andres/go-logsink
libs/netcore/Serilog.GoLogsinkSink/Serilog.GoLogsinkSink/LogsinkSink.cs
libs/netcore/Serilog.GoLogsinkSink/Serilog.GoLogsinkSink/LogsinkSink.cs
// Serilog.GoLogsinkSink::Serilog.GoLogsinkSink::LogsinkSink.cs // 2021-02-25 namespace Serilog.GoLogsinkSink { using System.IO; using Microsoft.Extensions.Logging; using System; using System.Collections.Generic; using System.Threading.Tasks; using Grpc.Net.Client; using Serilog.Events; using Serilog.Formattin...
// Serilog.GoLogsinkSink::Serilog.GoLogsinkSink::LogsinkSink.cs // 2021-02-25 namespace Serilog.GoLogsinkSink { using System.IO; using Microsoft.Extensions.Logging; using System; using System.Collections.Generic; using System.Threading.Tasks; using Grpc.Net.Client; using Serilog.Events; using Serilog.Formattin...
apache-2.0
C#
6c930f2c8576075926378678c62d2c4683162ea2
Bump version.
JohanLarsson/Gu.Wpf.Geometry
Gu.Wpf.Geometry/Properties/AssemblyInfo.cs
Gu.Wpf.Geometry/Properties/AssemblyInfo.cs
using System.Reflection; using System.Runtime.CompilerServices; using System.Runtime.InteropServices; using System.Windows; using System.Windows.Markup; [assembly: AssemblyTitle("Gu.Wpf.Geometry")] [assembly: AssemblyDescription("Geometries for WPF.")] [assembly: AssemblyConfiguration("")] [assembly: AssemblyCompany(...
using System.Reflection; using System.Runtime.CompilerServices; using System.Runtime.InteropServices; using System.Windows; using System.Windows.Markup; // General Information about an assembly is controlled through the following // set of attributes. Change these attribute values to modify the information // associa...
mit
C#
5a1783bc18906cdac2eee0f446a904514d571bd9
Update Array_HeapAllocVsStackAlloc.cs
redknightlois/BenchmarkDotNet,PerfDotNet/BenchmarkDotNet,adamsitnik/BenchmarkDotNet,adamsitnik/BenchmarkDotNet,ig-sinicyn/BenchmarkDotNet,alinasmirnova/BenchmarkDotNet,redknightlois/BenchmarkDotNet,PerfDotNet/BenchmarkDotNet,ig-sinicyn/BenchmarkDotNet,ig-sinicyn/BenchmarkDotNet,redknightlois/BenchmarkDotNet,alinasmirno...
BenchmarkDotNet.Samples/Other/Array_HeapAllocVsStackAlloc.cs
BenchmarkDotNet.Samples/Other/Array_HeapAllocVsStackAlloc.cs
namespace BenchmarkDotNet.Samples.Other { // See http://blogs.microsoft.co.il/sasha/2013/10/17/on-stackalloc-performance-and-the-large-object-heap/ // For comparision, the original "hand-written" benchmark is available at https://gist.github.com/goldshtn/7021608 public class Array_HeapAllocVsStackAlloc ...
namespace BenchmarkDotNet.Samples.Other { // See http://blogs.microsoft.co.il/sasha/2013/10/17/on-stackalloc-performance-and-the-large-object-heap/ // For comparision, the original "hand-written" benchmark is available at https://gist.github.com/goldshtn/7021608 public class Array_HeapAllocVsStackAlloc ...
mit
C#
7aeb68f950b809d84e3969010d2aba1157813c3e
Remove Unecessary region in Grade Summary
ApplETS/ETSMobile-WindowsPlatforms,ApplETS/ETSMobile-WindowsPlatforms
Ets.Mobile/Ets.Mobile.UWP/Content/Grade/GradeSummary.xaml.cs
Ets.Mobile/Ets.Mobile.UWP/Content/Grade/GradeSummary.xaml.cs
using System.ComponentModel; using System.Runtime.CompilerServices; using Windows.UI.Xaml; using Windows.UI.Xaml.Controls; using Windows.UI.Xaml.Media; namespace Ets.Mobile.Content.Grade { public sealed partial class GradeSummary : UserControl, INotifyPropertyChanged { public GradeSummary() { ...
using System.ComponentModel; using System.Runtime.CompilerServices; using Windows.UI.Xaml; using Windows.UI.Xaml.Controls; using Windows.UI.Xaml.Media; namespace Ets.Mobile.Content.Grade { public sealed partial class GradeSummary : UserControl, INotifyPropertyChanged { public GradeSummary() { ...
apache-2.0
C#
6a3916631d4b0d4149f3722044e1d267e36428a6
Clean Indentation
prime31/Nez,prime31/Nez,Blucky87/Nez,prime31/Nez,eumario/Nez,ericmbernier/Nez
PipelineImporter/Tiled/TiledMapImporter.cs
PipelineImporter/Tiled/TiledMapImporter.cs
using System; using System.Diagnostics; using System.IO; using System.Xml.Serialization; using Microsoft.Xna.Framework.Content.Pipeline; namespace Nez.TiledMaps { [ContentImporter( ".tmx", DefaultProcessor = "TiledMapProcessor", DisplayName = "Tiled Map Importer" )] public class TiledMapImporter : ContentImporter<...
using System; using System.Diagnostics; using System.IO; using System.Xml.Serialization; using Microsoft.Xna.Framework.Content.Pipeline; namespace Nez.TiledMaps { [ContentImporter( ".tmx", DefaultProcessor = "TiledMapProcessor", DisplayName = "Tiled Map Importer" )] public class TiledMapImporter : ContentImporter<...
mit
C#
07d58b0b79ff3861a8f9c01b9147ad6e76a059c7
make test work in any timezone
neutmute/loggly-csharp
source/Loggly.Tests/Loggly/ExtensionMethods/DateTimeExtensionsFixture.cs
source/Loggly.Tests/Loggly/ExtensionMethods/DateTimeExtensionsFixture.cs
using System; using System.Collections.Generic; using System.Linq; using System.Text; using System.Threading.Tasks; using NUnit.Framework; namespace Loggly.Tests.Loggly.ExtensionMethods { public class DateTimeExtensionsFixture : Fixture { /// <summary> /// https://www.loggly.com/docs/automated...
using System; using System.Collections.Generic; using System.Linq; using System.Text; using System.Threading.Tasks; using NUnit.Framework; namespace Loggly.Tests.Loggly.ExtensionMethods { public class DateTimeExtensionsFixture : Fixture { /// <summary> /// https://www.loggly.com/docs/automated...
mit
C#
ab1c09aaf65c86013e222d3adaee8bee31bd11aa
Make that a bit clearer.
eightyeight/t3d-bones,eightyeight/t3d-bones
main.cs
main.cs
// Display a splash window immediately to improve app responsiveness before // engine is initialized and main window created displaySplashWindow("splash.bmp"); // Console does something. setLogMode(2); // Disable script trace. trace(false); //---------------------------------------------------------------------------...
// Display a splash window immediately to improve app responsiveness before // engine is initialized and main window created displaySplashWindow("splash.bmp"); // Console does something. setLogMode(2); // Disable script trace. trace(false); //---------------------------------------------------------------------------...
mit
C#
584db81d10366b07a628b003bfe67437552d71ea
change DisIO as generic
addyi/SoftwareCity
Assets/Scripts/DiskIO/DiskIOManager/DiskIO.cs
Assets/Scripts/DiskIO/DiskIOManager/DiskIO.cs
using System.Collections.Generic; using System.IO; using DiskIO.ReadConfigFile; namespace DiskIO.DiskIOManager { public class DiskIO<Type> { public readonly string directoryPath = @"/hololens/directory/path/where/componentTree/should-be-saved "; public readonly string filePath = @"/file/path/...
using System.Collections.Generic; using System.IO; using QAware.DataStorage.DataEntertainment; using DiskIO.ReadConfigFile; namespace DiskIO.DiskIOManager { public class DiskIO { private readonly string directoryPath = @"/Users/yacinesghairi/Desktop"; public DiskIO() { } //public Confi...
mit
C#
ff5f4af09e1a5dd1d0d5f4941f8dfe113a67d1a9
Fix CircleShape debug rendering
lucas-miranda/Raccoon
Raccoon/Core/Physics/Shapes/CircleShape.cs
Raccoon/Core/Physics/Shapes/CircleShape.cs
using Raccoon.Graphics; using Raccoon.Util; namespace Raccoon { public class CircleShape : IShape { private Vector2 _origin; public CircleShape(int radius) { Radius = radius; BoundingBox = new Rectangle(new Vector2(-Radius), new Size(Radius + Radius)); Area = (...
using Raccoon.Graphics; using Raccoon.Util; namespace Raccoon { public class CircleShape : IShape { private Vector2 _origin; public CircleShape(int radius) { Radius = radius; BoundingBox = new Rectangle(new Vector2(-Radius), new Size(Radius + Radius)); Area = (...
mit
C#
57c36b9c595a81a16085cda66519e6298e3b17ef
Fix order by issue
twllaw/MyFileRenamer
AudioFileAssistant/Helpers/DirectoryHelper.cs
AudioFileAssistant/Helpers/DirectoryHelper.cs
using System.IO; using System.Linq; using TagLib; using System.Collections.Generic; namespace AudioFileAssistant.Helpers { public static class DirectoryHelper { public static bool IsValidDirectory(string path) { if (string.IsNullOrEmpty(path) || !Directory.Exists(path)) ...
using System.IO; using System.Linq; using TagLib; using System.Collections.Generic; namespace AudioFileAssistant.Helpers { public static class DirectoryHelper { public static bool IsValidDirectory(string path) { if (string.IsNullOrEmpty(path) || !Directory.Exists(path)) ...
mit
C#
f512c558c38b6656bdcc2a8bd4a0722af71ceef0
Fix typo
mattgwagner/Battery-Commander,mattgwagner/Battery-Commander,mattgwagner/Battery-Commander,mattgwagner/Battery-Commander
Battery-Commander.Web/Services/UserService.cs
Battery-Commander.Web/Services/UserService.cs
using BatteryCommander.Web.Models; using Microsoft.IdentityModel.Tokens; using System; using System.IdentityModel.Tokens.Jwt; using System.Linq; using System.Security.Claims; using System.Text; using System.Threading.Tasks; namespace BatteryCommander.Web.Services { public class UserService { /// <summ...
using BatteryCommander.Web.Models; using Microsoft.IdentityModel.Tokens; using System; using System.IdentityModel.Tokens.Jwt; using System.Linq; using System.Security.Claims; using System.Text; using System.Threading.Tasks; namespace BatteryCommander.Web.Services { public class UserService { /// <summ...
mit
C#
3f55a20689394edd18dcf45f4c466c1ce43279b7
Remove unnecessary '@' before arg name
Weingartner/SolidworksAddinFramework
SolidworksAddinFramework/OpenGl/Animation/LinearAnimation.cs
SolidworksAddinFramework/OpenGl/Animation/LinearAnimation.cs
using System; using System.Diagnostics; using System.Numerics; using ReactiveUI; namespace SolidworksAddinFramework.OpenGl.Animation { public class LinearAnimation<T> : ReactiveObject, IAnimationSection where T : IInterpolatable<T> { public T From { get; } public T To { get; } ...
using System; using System.Diagnostics; using System.Numerics; using ReactiveUI; namespace SolidworksAddinFramework.OpenGl.Animation { public class LinearAnimation<T> : ReactiveObject, IAnimationSection where T : IInterpolatable<T> { public T From { get; } public T To { get; } ...
mit
C#
d8a8e36adee1198a135bdfd9ed80bdbaf758c8d3
Add null check for memberInfo parameter.
tareq-s/Swashbuckle,Driedas/Swashbuckle,lostllama/Swashbuckle,jruckert/Swashbuckle,jruckert/Swashbuckle,yonglehou/Swashbuckle,lostllama/Swashbuckle,Atomosk/Swashbuckle,svickers/Swashbuckle,kienct89/Swashbuckle,henning-krause/Swashbuckle,Atomosk/Swashbuckle,xMarkos/Swashbuckle,svickers/Swashbuckle,VirtoCommerce/Swashbuc...
Swashbuckle.Core/Swagger/XmlComments/ApplyXmlTypeComments.cs
Swashbuckle.Core/Swagger/XmlComments/ApplyXmlTypeComments.cs
using System; using System.Xml.XPath; using System.Linq; using System.Collections.Generic; using System.Text; using System.Reflection; using Newtonsoft.Json.Serialization; using Swashbuckle.Swagger; namespace Swashbuckle.Swagger.XmlComments { public class ApplyXmlTypeComments : IModelFilter { private ...
using System; using System.Xml.XPath; using System.Linq; using System.Collections.Generic; using System.Text; using System.Reflection; using Newtonsoft.Json.Serialization; using Swashbuckle.Swagger; namespace Swashbuckle.Swagger.XmlComments { public class ApplyXmlTypeComments : IModelFilter { private ...
bsd-3-clause
C#
0c039797b0881711a21e9b10bfa7621a468d2e3d
Move version to test 8.9
jthorpe4/EDDiscovery,jgoode/EDDiscovery,jgoode/EDDiscovery,mwerle/EDDiscovery,mwerle/EDDiscovery
EDDiscovery/Properties/AssemblyInfo.cs
EDDiscovery/Properties/AssemblyInfo.cs
/* * Copyright © 2015 - 2017 EDDiscovery development team * * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this * file except in compliance with the License. You may obtain a copy of the License at * * http://www.apache.org/licenses/LICENSE-2.0 * * Unless required by applica...
/* * Copyright © 2015 - 2017 EDDiscovery development team * * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this * file except in compliance with the License. You may obtain a copy of the License at * * http://www.apache.org/licenses/LICENSE-2.0 * * Unless required by applica...
apache-2.0
C#
581c2282b05c2068a5c73522eacbdcdd20396ca2
Add dispose for session if the session is not null. This means that the session is created with the uow
generik0/Smooth.IoC.Dapper.Repository.UnitOfWork,generik0/Smooth.IoC.Dapper.Repository.UnitOfWork
src/Smooth.IoC.Dapper.Repository.UnitOfWork/Data/DbTransaction.cs
src/Smooth.IoC.Dapper.Repository.UnitOfWork/Data/DbTransaction.cs
using System; using System.Data; namespace Smooth.IoC.Dapper.Repository.UnitOfWork.Data { public abstract class DbTransaction : IDbTransaction { private readonly IDbFactory _factory; protected bool Disposed; protected ISession Session; public IDbTransaction Transaction { get; s...
using System; using System.Data; namespace Smooth.IoC.Dapper.Repository.UnitOfWork.Data { public abstract class DbTransaction : IDbTransaction { private readonly IDbFactory _factory; protected bool Disposed; public IDbTransaction Transaction { get; set; } public IDbConnection C...
mit
C#
2d1f80b78e56c0de7fa7e766d5f83690b9200dd0
update test/AspectCore.Abstractions.Test/Fakes/AspectValidatorFactory
AspectCore/Abstractions,AspectCore/Lite,AspectCore/AspectCore-Framework,AspectCore/AspectCore-Framework
test/AspectCore.Abstractions.Test/Fakes/AspectValidatorFactory.cs
test/AspectCore.Abstractions.Test/Fakes/AspectValidatorFactory.cs
using System.Collections.Generic; using AspectCore.Abstractions.Internal; namespace AspectCore.Abstractions.Test.Fakes { public class AspectValidatorFactory { public static IAspectValidator GetAspectValidator(IAspectConfigure configure) { var handlers = new List<IAspectValidationHa...
using System.Collections.Generic; using AspectCore.Abstractions.Internal; namespace AspectCore.Abstractions.Test.Fakes { public class AspectValidatorFactory { public static IAspectValidator GetAspectValidator(IAspectConfigure configure) { var handlers = new List<IAspectValidationHa...
mit
C#
a708029250604b7cec6c7af314d1c68c99f83215
Fix unit test
dotnetcore/CAP,ouraspnet/cap,dotnetcore/CAP,dotnetcore/CAP
test/DotNetCore.CAP.CastleCoreTest/ConsumerServiceSelectorTest.cs
test/DotNetCore.CAP.CastleCoreTest/ConsumerServiceSelectorTest.cs
using Castle.DynamicProxy; using Microsoft.Extensions.DependencyInjection; using Microsoft.Extensions.DependencyInjection.Extensions; using System; using Xunit; namespace DotNetCore.CAP.CastleDynamicProxyTest { public class ConsumerServiceSelectorTest { private IServiceProvider _provider; publ...
using Castle.DynamicProxy; using Microsoft.Extensions.DependencyInjection; using Microsoft.Extensions.DependencyInjection.Extensions; using System; using Xunit; namespace DotNetCore.CAP.CastleDynamicProxyTest { public class ConsumerServiceSelectorTest { private IServiceProvider _provider; publ...
mit
C#
c8a71e5d19495584d6a5777054249369d11c4386
Implement accessor for AudioSource
umm-projects/animationevent_dispatcher
Assets/Scripts/UnityModule/AnimationEventDispatcher/AudioDispatcher.cs
Assets/Scripts/UnityModule/AnimationEventDispatcher/AudioDispatcher.cs
using System.Collections; using System.Collections.Generic; using GameObjectExtension; using UnityEngine; namespace UnityModule.AnimationEventDispatcher { public class AudioDispatcher : MonoBehaviour { /// <summary> /// AudioSource の実体 /// </summary> private AudioSource audioSour...
using System.Collections; using System.Collections.Generic; using UnityEngine; public class AudioDispatcher : MonoBehaviour { // Use this for initialization void Start () { } // Update is called once per frame void Update () { } }
mit
C#